RecurringSaleResponseCallback class

Inheritance

Constructors

RecurringSaleResponseCallback({required dynamic success(MontypaySaleSuccess result), required dynamic decline(MontypaySaleDecline result), required dynamic recurring(MontypaySaleRecurring result), required dynamic redirect(MontypaySaleRedirect result), required dynamic secure3d(MontypaySale3DS result), required dynamic error(MontypayError result)})

Properties

decline → dynamic Function(MontypaySaleDecline result)
finalinherited
error → dynamic Function(MontypayError result)
finalinherited
hashCode int
The hash code for this object.
no setterinherited
recurring → dynamic Function(MontypaySaleRecurring result)
finalinherited
redirect → dynamic Function(MontypaySaleRedirect result)
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secure3d → dynamic Function(MontypaySale3DS result)
finalinherited
success → dynamic Function(MontypaySaleSuccess result)
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited