CaptureResponseCallback class
Constructors
- CaptureResponseCallback({required dynamic success(MontypayCaptureSuccess result), required dynamic decline(MontypayCaptureDecline result), required dynamic error(MontypayError result)})
Properties
- decline → dynamic Function(MontypayCaptureDecline result)
-
final
- error → dynamic Function(MontypayError result)
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → dynamic Function(MontypayCaptureSuccess result)
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited