MontypayStatus enum
Status – actual status of transaction in Payment Platform. @see com.montypay.sdk.model.response.base.result.IMontypayResult
@property status the status value.
Values
- SECURE_3D → const MontypayStatus
-
The transaction awaits 3D-Secure validation.
const MontypayStatus("3DS") - REDIRECT → const MontypayStatus
-
The transaction is redirected.
const MontypayStatus("REDIRECT") - PENDING → const MontypayStatus
-
The transaction awaits CAPTURE.
const MontypayStatus("PENDING") - SETTLED → const MontypayStatus
-
Successful transaction.
const MontypayStatus("SETTLED") - REVERSAL → const MontypayStatus
-
Transaction for which reversal was made.
const MontypayStatus("REVERSAL") - REFUND → const MontypayStatus
-
Transaction for which refund was made.
const MontypayStatus("REFUND") - CHARGEBACK → const MontypayStatus
-
Transaction for which chargeback was made.
const MontypayStatus("CHARGEBACK") - DECLINED → const MontypayStatus
-
Not successful transaction.
const MontypayStatus("DECLINED") - NONE → const MontypayStatus
-
const MontypayStatus("NONE")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MontypayStatus> - A constant List of the values in this enum, in order of their declaration.